@@ -56,6 +56,7 @@ namespace QGpCoreStat {
     _yColumn=1;
     _validColumn=-1;
     _maxVariables=SlownessFrequency;
+    _noiseColumn=-1;
     _powerColumn=-1;
     _relativePowerThreshold=0.0;
     _noiseThreshold=std::numeric_limits<double>::infinity();
@@ -336,7 +337,7 @@ namespace QGpCoreStat {
       }
       if(sumLin<sumLog) {
         if(!_xSampling) {
-          App::log(tr("Identified a linear scale for\n"));
+          App::log(tr("Identified a linear scale for X\n"));
         }
         _xLogSampling=false;
       } else {
@@ -346,7 +347,7 @@ namespace QGpCoreStat {
         _xLogSampling=true;
       }
     }
-    if(!_manual.xValuesAsIs) {
+    if(!_manual.xValuesAsIs && !_xSampling) {
       _xSampling=new SamplingParameters;
     }
     if(_xSampling) {
@@ -358,7 +359,7 @@ namespace QGpCoreStat {
         if(!_manual.x.minimum) {
           _xSampling->setMinimum(_xValues.first());
         }
-        if(!_manual.x.minimum) {
+        if(!_manual.x.maximum) {
           _xSampling->setMaximum(_xValues.last());
         }
       }
@@ -522,6 +523,9 @@ namespace QGpCoreStat {
       SampleFilter filter;
       if(File::isDataLine(lastLine, _pattern)) {
         if(sample.read(lastLine, _xColumn, _yColumn, _noiseColumn, _powerColumn, _validColumn)) {
+          if(_yFactor!=1.0) {
+            sample.setY(sample.y()*_yFactor);
+          }
           filter.append(sample);
         } else {
           ok=false;
@@ -530,6 +534,9 @@ namespace QGpCoreStat {
       while(!s.atEnd()) {
         if(File::readLine(s, line, _pattern)) {
           if(sample.read(line, _xColumn, _yColumn, _noiseColumn, _powerColumn, _validColumn)) {
+            if(_yFactor!=1.0) {
+              sample.setY(sample.y()*_yFactor);
+            }
             filter.append(sample);
           } else {
             ok=false;
@@ -638,12 +645,14 @@ namespace QGpCoreStat {
   {
     TRACE;
     Histogram2D * h;
-    static const QString msg=tr("X axis from %1 to %2 with %3 bins\n");
+    static const QString msg=tr("%5 axis from %1 to %2 with %3 samples (step=%4)\n");
     if(_xSampling) {
        h=new Histogram2D(_xSampling->count(), _ySampling.count());
-       App::log(msg.arg(_xSampling->minimum())
-                   .arg(_xSampling->maximum())
-                   .arg(_xSampling->count()));
+       App::log(msg.arg(_xSampling->value(0))
+                   .arg(_xSampling->value(_xSampling->count()-1))
+                   .arg(_xSampling->count())
+                   .arg(_xSampling->step())
+                   .arg("X"));
        if(!h->setXSampling(*_xSampling)) {
          delete h;
          return nullptr;
@@ -652,7 +661,9 @@ namespace QGpCoreStat {
       h=new Histogram2D(_xValues.count(), _ySampling.count());
       App::log(msg.arg(_xValues.first())
                   .arg(_xValues.last())
-                  .arg(_xValues.count()));
+                  .arg(_xValues.count())
+                  .arg("asis")
+                  .arg("X"));
       if(!h->setXSampling(_xValues)) {
         delete h;
         return nullptr;
@@ -669,10 +680,11 @@ namespace QGpCoreStat {
         h->setXScaleType(Scale::Linear);
       }
     }
-    App::log(tr("Y axis from %1 to %2 with %3 bins\n")
-             .arg(_ySampling.minimum())
-             .arg(_ySampling.maximum())
-             .arg(_ySampling.count()));
+    App::log(msg.arg(_ySampling.value(0))
+                .arg(_ySampling.value(_ySampling.count()-1))
+                .arg(_ySampling.count())
+                .arg(_ySampling.step())
+                .arg("Y"));
     if(!h->setYSampling(_ySampling)) {
       delete h;
       return nullptr;
@@ -719,7 +731,7 @@ namespace QGpCoreStat {
         _validColumn=6;
       }
     } else if(line=="# time frequency polarization slowness azimuth valid") {
-      // Compatibility for results from September and October 2017
+      // Compatibility for results from September to October 2017
       // Option -ell* will ouput junk for these results
       if(!_ignoreValid) {
         _validColumn=5;
@@ -946,7 +958,6 @@ namespace QGpCoreStat {
   void HistogramReader::configureCapMaxFile()
   {
     _headerLine="# abs_time frequency polarization slowness azimuth ellipticity noise power valid\n";
-    _headerLine="# time frequency polarization slowness azimuth ellipticity valid\n";
     _xTitle=tr("Frequency (Hz)");
     _xColumn=1;
     switch(_maxVariables) {
@@ -954,19 +965,27 @@ namespace QGpCoreStat {
       _yTitle=tr("Slowness (s/m)");
       _yFactor=0.001;
       _yColumn=2;
-      _ySampling.setMinimum(1.0/3500.0);
-      _manual.y.minimum=true;
-      _ySampling.setType(SamplingParameters::Log);
-      _manual.y.gridScaleType=true;
+      if(!_manual.y.minimum) {
+        _ySampling.setMinimum(1.0/3500.0);
+        _manual.y.minimum=true;
+      }
+      if(!_manual.y.gridScaleType) {
+        _ySampling.setType(SamplingParameters::Log);
+        _manual.y.gridScaleType=true;
+      }
       _validColumn=-1;
       break;
     case AzimuthFrequency:
       _yTitle=tr("Azimuth (degrees)");
       _yColumn=3;
-      _ySampling.setMinimum(0.0);
-      _ySampling.setMaximum(360.0);
-      _manual.y.minimum=true;
-      _manual.y.maximum=true;
+      if(!_manual.y.minimum) {
+        _ySampling.setMinimum(0.0);
+        _manual.y.minimum=true;
+      }
+      if(!_manual.y.maximum) {
+        _ySampling.setMaximum(360.0);
+        _manual.y.maximum=true;
+      }
       _validColumn=-1;
       break;
     case EllipticityFrequency:
